Documentation
¶
Overview ¶
Package card models the standard 52-card deck of French playing cards.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Card ¶
type Card struct {
// contains filtered or unexported fields
}
Card represents a playing card in a standard 52-card deck.
type Deck ¶
type Deck struct {
// contains filtered or unexported fields
}
Deck represents a standard 52-card deck of French playing cards.
func NewDeck ¶
func NewDeck() *Deck
NewDeck creates a new deck of playing card. The cards in the deck are shuffled.
type Game ¶
type Game interface {
// Name returns the name of the game.
Name() string
// Players returns the list of participants involved in the game.
Players() []Player
}
Game is the abstraction for any game played with standard French playing cards.
type Rank ¶
type Rank int
Rank represents one of the thirteen ranks in a deck of playing cards.
The thirteen ranks in each of the four suits.
Click to show internal directories.
Click to hide internal directories.